Home

- Home
- Setup
- Program
- Manage
- Logout

Time | Today | Sat | Sun | Mon
09:01 AM | 55 - 35° | 66 - 34° | 69 - 50° | 55 - 42°

Control Unit:
Online
66%
Valve Unit:
Online
0
0
0
0

## Zone | 1 - Front Yard | 2 | 3 | 4

## Manual |  |  |  |

## Auto |  |  |  |
### Edit |  |  |  |
### Rain Delay |  |  |  |
### Next Cycle | Off | Off | Off | Off

Copyright © 2016 Melnor, Inc. All Rights Reserved. Forecast by OpenWeatherMap